@@ -582,6 +582,7 @@ namespace G2Export {
 			export_dialog = (Gtk.Dialog) xml.GetWidget ("gallery_export_dialog");
 
 			this.items = selection.Items;
+			Array.Sort(this.items as Photo[], new Photo.CompareDateName());
 			album_button.Sensitive = false;
 			IconView view = new IconView (selection);
 			view.DisplayDates = false;
@@ -771,7 +772,7 @@ namespace G2Export {
 			progress_dialog.ButtonLabel = Gtk.Stock.Ok;
 			
 			if (browser) {
-				GnomeUtil.UrlShow (null, album.GetUrl());
+				GnomeUtil.UrlShow (album.GetUrl());
 			}
 		}
 		
