@@ -15,6 +15,7 @@ using Gtk;
 using Glade;
 using LibGPhoto2;
 using Mono.Unix;
+using FSpot.UI.Dialog;
 
 namespace FSpot {
 	public class CameraFileSelectionDialog : GladeDialog
@@ -139,7 +140,9 @@ namespace FSpot {
 				
 				int index = 0;
 				bool load_thumb = true;
-				foreach (GPhotoCameraFile file in camera.FileList) {
+				System.Collections.ArrayList sfiles = camera.FileList;
+				sfiles.Sort ();
+				foreach (GPhotoCameraFile file in sfiles) {
 					string msg = String.Format (Catalog.GetString ("Downloading Preview of {0}"), 
 								    file.FileName);
 					
