@@ -6,11 +6,9 @@
  */
 
 namespace FSpot {
-	public class Global {
+	public static class Global {
 		public static string HomeDirectory {
-			get {
-				return System.IO.Path.Combine (System.Environment.GetEnvironmentVariable ("HOME"), System.String.Empty);	
-			}
+			get { return System.IO.Path.Combine (System.Environment.GetEnvironmentVariable ("HOME"), System.String.Empty); }
 		}
 		
 		private static string base_dir = System.IO.Path.Combine (HomeDirectory,  System.IO.Path.Combine (".gnome2", "f-spot"));
@@ -54,5 +52,17 @@ namespace FSpot {
 				return icon_theme;
 			}
 		}
+
+#if GTK_2_12_2
+		private static string [] default_rc_files = null;
+		public static string [] DefaultRcFiles {
+			get {
+				if (default_rc_files == null)
+					default_rc_files = Gtk.Rc.DefaultFiles;
+				return default_rc_files;
+			}
+			set { default_rc_files = value; }
+		}
+#endif
 	}
 }
