@@ -14,6 +14,8 @@ using System;
 using Cairo;
 using Mono.Unix;
 
+using FSpot.UI.Dialog;
+using FSpot.Utils;
 namespace FSpot.Editors {
 	public class SoftFocus : EffectEditor {
 		Widgets.SoftFocus soft; 
@@ -52,10 +54,10 @@ namespace FSpot.Editors {
 			box.PackStart (scale);
 			HBox actions = new HBox ();
 			actions.Spacing = 12;
-			Button cancel = new Button (Catalog.GetString ("Cancel"));
+			Button cancel = new Button (Stock.Cancel);
 			cancel.Clicked += HandleCancel;
 			actions.PackStart (cancel);
-			Button apply = new Button ( Catalog.GetString ("Apply"));
+			Button apply = new Button (Stock.Apply);
 			apply.Clicked += HandleApply;
 			actions.PackStart (apply);
 			box.PackStart (actions);
@@ -100,7 +102,7 @@ namespace FSpot.Editors {
 					// goodies we'll need.
 					//Gnome.Vfs.Result result = Gnome.Vfs.Result.Ok;
 					//result = Gnome.Vfs.Xfer.XferUri (new Gnome.Vfs.Uri (UriList.PathToFileUri (tmp).ToString ()),
-					Gnome.Vfs.Xfer.XferUri (new Gnome.Vfs.Uri (UriList.PathToFileUri (tmp).ToString ()),
+					Gnome.Vfs.Xfer.XferUri (new Gnome.Vfs.Uri (UriUtils.PathToFileUri (tmp).ToString ()),
 						new Gnome.Vfs.Uri (target.Uri.ToString ()),
 						Gnome.Vfs.XferOptions.Default,
 						Gnome.Vfs.XferErrorMode.Abort, 
