@@ -1,6 +1,7 @@
 using SemWeb;
 using SemWeb.Util;
-using Mono.Posix;
+using Mono.Unix;
+using FSpot.Xmp;
 
 namespace FSpot {
         internal class Description {
@@ -86,7 +87,6 @@ namespace FSpot {
 		public Description (string predicate, string title, string description, ValueFormat formater)
 		{
 			this.predicate = predicate;
-			this.description = description;
 			this.title = title;
 			this.formater = formater;
 		}
@@ -100,13 +100,13 @@ namespace FSpot {
 			label = System.IO.Path.GetFileName (predicate);
 			value = null;
 
-			if (stmt.Object is Literal)
-			        value = ((Literal)(stmt.Object)).Value;
+			if (stmt.Object is SemWeb.Literal)
+			        value = ((SemWeb.Literal)(stmt.Object)).Value;
 
 			if (d != null) {
 				label = d.title;
 				if (d.formater != null && stmt.Object is Literal)
-					value = d.formater.GetValue (store, (Literal)stmt.Object);
+					value = d.formater.GetValue (store, (SemWeb.Literal)stmt.Object);
 
 			} else {
 				Statement sstmt = new Statement (stmt.Predicate,
@@ -114,8 +114,8 @@ namespace FSpot {
 								 null);
 				
 				foreach (Statement tstmt in MetadataStore.Descriptions.Select (sstmt))
-					if (tstmt.Object is Literal)
-						label = ((Literal)(tstmt.Object)).Value;
+					if (tstmt.Object is SemWeb.Literal)
+						label = ((SemWeb.Literal)(tstmt.Object)).Value;
 			}
 			return;
 		}
@@ -130,7 +130,7 @@ namespace FSpot {
 			this.type = type;
 		}
 
-		public virtual string GetValue (MemoryStore store, Literal obj)
+		public virtual string GetValue (MemoryStore store, SemWeb.Literal obj)
 		{
 			string result = obj.Value;
 
@@ -139,7 +139,7 @@ namespace FSpot {
 					object o = System.Enum.Parse (type, obj.Value);
 					result = o.ToString ();
 				} catch (System.Exception e) {
-					System.Console.WriteLine ("Value \"{2}\" not found in {0}\n{1}", type, e, result);
+					System.Console.WriteLine ("Value \"{2}\" not found in {0}{3}{1}", type, e, result, System.Environment.NewLine);
 				}
 			}
 			/*
@@ -150,28 +150,47 @@ namespace FSpot {
 			return result;
 		}
 	}
-
+	
 	public class MetadataStore : MemoryStore
 	{
 		public static NamespaceManager Namespaces;
 		private static MetadataStore descriptions;
+		
+		public const string PhotoshopNS = "http://ns.adobe.com/photoshop/1.0/";
+		public const string Iptc4xmpCoreNS = "http://iptc.org/std/Iptc4xmpCore/1.0/xmlns/";
+		public const string DcNS = "http://purl.org/dc/elements/1.1/";
+		public const string XmpNS = "http://ns.adobe.com/xap/1.0/";
+		public const string XmpidqNS = "http://ns.adobe.com/xmp/Identifier/qual/1.0/";
+		public const string XmpRightsNS = "http://ns.adobe.com/xap/1.0/rights/";
+		public const string XmpBJNS = "http://ns.adobe.com/xap/1.0/bj/";
+		public const string XmpMMNS = "http://ns.adobe.com/xap/1.0/mm/";
+		public const string ExifNS = "http://ns.adobe.com/exif/1.0/";
+		public const string TiffNS = "http://ns.adobe.com/tiff/1.0/";
+		public const string RdfNS = "http://www.w3.org/1999/02/22-rdf-syntax-ns#";
+		public const string RdfsNS = "http://www.w3.org/2000/01/rdf-schema#";
+		public const string IViewNS = "http://ns.iview-multimedia.com/mediapro/1.0/";
+		public const string XmlNS = "http://iptc.org/std/Iptc4xmpCore/1.0/xmlns/";
+
+		// FIXME this needs to be parsable by System.Uri
+		public const string FSpotXMPBase = "http://fakebase.f-spot.org/internal/";
 
 		static MetadataStore ()
 		{
 			Namespaces = new NamespaceManager ();
 			
-			Namespaces.AddNamespace ("http://ns.adobe.com/photoshop/1.0/", "photoshop");
-			Namespaces.AddNamespace ("http://iptc.org/std/Iptc4xmpCore/1.0/xmlns/", "Iptc4xmpCore");
-			Namespaces.AddNamespace ("http://purl.org/dc/elements/1.1/", "dc");
-			Namespaces.AddNamespace ("http://ns.adobe.com/xap/1.0/", "xmp");
-			Namespaces.AddNamespace ("http://ns.adobe.com/xmp/Identifier/qual/1.0", "xmpidq");
-			Namespaces.AddNamespace ("http://ns.adobe.com/xap/1.0/rights/", "xmpRights");
-			Namespaces.AddNamespace ("http://ns.adobe.com/xap/1.0/bj/", "xmpBJ");
-			Namespaces.AddNamespace ("http://ns.adobe.com/xap/1.0/mm/", "xmpMM");
-			Namespaces.AddNamespace ("http://ns.adobe.com/exif/1.0/", "exif");
-			Namespaces.AddNamespace ("http://ns.adobe.com/tiff/1.0/", "tiff");
-			Namespaces.AddNamespace ("http://www.w3.org/1999/02/22-rdf-syntax-ns#", "rdf");
-			Namespaces.AddNamespace ("http://www.w3.org/2000/01/rdf-schema#", "rdfs");
+			Namespaces.AddNamespace (PhotoshopNS, "photoshop");
+			Namespaces.AddNamespace (Iptc4xmpCoreNS, "Iptc4xmpCore");
+			Namespaces.AddNamespace (DcNS, "dc");
+			Namespaces.AddNamespace (XmpNS, "xmp");
+			Namespaces.AddNamespace (XmpidqNS, "xmpidq");
+			Namespaces.AddNamespace (XmpRightsNS, "xmpRights");
+			Namespaces.AddNamespace (XmpBJNS, "xmpBJ");
+			Namespaces.AddNamespace (XmpMMNS, "xmpMM");
+			Namespaces.AddNamespace (ExifNS, "exif");
+			Namespaces.AddNamespace (TiffNS, "tiff");
+			Namespaces.AddNamespace (RdfNS, "rdf");
+			Namespaces.AddNamespace (RdfsNS, "rdfs");
+			Namespaces.AddNamespace (IViewNS, "mediapro");
 		}
 
 		public static MetadataStore Descriptions {
@@ -192,30 +211,17 @@ namespace FSpot {
 
 		public void Dump ()
 		{
-			foreach (SemWeb.Statement stmt in this) {
-				System.Console.WriteLine(stmt);
-			}
-
-			/*
-			XPathSemWebNavigator navi = new XPathSemWebNavigator (this, Namespaces);
-			navi.MoveToRoot ();
-			navi.MoveToFirstChild ();
-			navi.MoveToFirstChild ();
-			DumpNode (navi, 0);
-			*/
-
-			/* Use the statement writer to filter the messages */
-			/*
-			foreach (string nspace in Namespaces.GetNamespaces ()) {
-				this.Select (new StatementWriter (nspace));
-			}
-			*/
+#if enable_debug
+			XmpFile xmp = new XmpFile ();
+			xmp.Store = this;
+			xmp.Save (System.Console.OpenStandardOutput ());
+#endif
 		}
 
-		public static void AddLiteral (StatementSink sink, string predicate, string type, Literal value)
+		public static void AddLiteral (StatementSink sink, string predicate, string type, SemWeb.Literal value)
 		{
 			Entity empty = new BNode ();
-			Statement top = new Statement (new BNode (), (Entity)MetadataStore.Namespaces.Resolve (predicate), empty);
+			Statement top = new Statement (FSpotXMPBase, (Entity)MetadataStore.Namespaces.Resolve (predicate), empty);
 			Statement desc = new Statement (empty, 
 							(Entity)MetadataStore.Namespaces.Resolve ("rdf:type"), 
 							(Entity)MetadataStore.Namespaces.Resolve (type));
@@ -229,15 +235,37 @@ namespace FSpot {
 
 		public static void AddLiteral (StatementSink sink, string predicate, string value)
 		{
-			Statement stmt = new Statement (new BNode (), 
+			Statement stmt = new Statement (FSpotXMPBase,
 							(Entity)MetadataStore.Namespaces.Resolve (predicate), 
-							new Literal (value));
+							new SemWeb.Literal (value));
 			sink.Add (stmt);
 		}
 
 		public static void Add (StatementSink sink, string predicate, string type, string [] values)
 		{
-			Add (sink, new BNode(), predicate, type, values);
+			Add (sink, FSpotXMPBase, predicate, type, values);
+		}
+
+		public void Delete (string predicate)
+		{
+			System.Collections.ArrayList to_remove = new System.Collections.ArrayList ();
+			foreach (Statement stmt in this) {
+				if (stmt.Predicate == MetadataStore.Namespaces.Resolve (predicate)) {
+					to_remove.Add (stmt);
+					break;
+				}
+			}
+
+			foreach (Statement stmt in to_remove)
+				this.Remove (stmt);
+		}
+
+		public void Update (string predicate, string value1)
+		{
+			// Delete first..
+			Delete (predicate);
+			// Add after...
+			AddLiteral (this, predicate, value1);
 		}
 
 		public void Update (string predicate, string type, string [] values)
@@ -247,7 +275,8 @@ namespace FSpot {
 			System.Collections.ArrayList to_remove = new System.Collections.ArrayList ();
 			foreach (Statement stmt in this) {
 				if (stmt.Predicate == MetadataStore.Namespaces.Resolve (predicate)) {
-					anon = (Entity) stmt.Object;
+					if (type != null) // only look further if we have a type.
+						anon = (Entity) stmt.Object;
 					to_remove.Add (stmt);
 					break;
 				}
@@ -285,7 +314,7 @@ namespace FSpot {
 			foreach (string value in values) {
 				Statement literal = new Statement (empty,
 								   (Entity)MetadataStore.Namespaces.Resolve ("rdf:li"),
-								   new Literal (value, null, null));
+								   new SemWeb.Literal (value, null, null));
 				sink.Add (literal);
 			}
 			sink.Add (top);
