@@ -173,7 +173,7 @@ public class PhotoStore : DbStore {
 				"INSERT INTO photos (time, uri, description, roll_id, default_version_id, rating) "	+
 	 			"VALUES (:time, :uri, :description, :roll_id, :default_version_id, :rating)",
 	 			"time", unix_time,
-				"uri", new_uri.ToString (),
+				"uri", new_uri.OriginalString,
 	 			"description", description,
 				"roll_id", roll_id,
 	 			"default_version_id", Photo.OriginalVersionId,
@@ -197,7 +197,11 @@ public class PhotoStore : DbStore {
 		while (reader.Read ()) {
 			uint version_id = Convert.ToUInt32 (reader [0]);
 			string name = reader[1].ToString ();
+#if MONO_2_0
 			System.Uri uri = new System.Uri (reader[2].ToString ());
+#else
+			System.Uri uri = new System.Uri (reader[2].ToString (), true);
+#endif
 			bool is_protected = Convert.ToBoolean (reader[3]);
 			photo.AddVersionUnsafely (version_id, uri, name, is_protected);
 		}
@@ -236,7 +240,11 @@ public class PhotoStore : DbStore {
 			if (reader [1] != null) {
 				uint version_id = Convert.ToUInt32 (reader [1]);
 				string name = reader[2].ToString ();
+#if MONO_2_0
 				System.Uri uri = new System.Uri (reader[3].ToString ());
+#else
+				System.Uri uri = new System.Uri (reader[3].ToString (), true);
+#endif
 				bool is_protected = Convert.ToBoolean (reader[4]);	
 				photo.AddVersionUnsafely (version_id, uri, name, is_protected);
 			}
@@ -277,30 +285,6 @@ public class PhotoStore : DbStore {
 		reader.Close();
 	}
 
-	private void GetData (Photo photo)
-	{
-		SqliteDataReader reader = Database.Query(new DbCommand("SELECT tag_id, version_id, name, uri, protected "
-                                                             + "FROM photo_tags, photo_versions "
-                                                             + "WHERE photo_tags.photo_id = photo_versions.photo_id "
-                                                             + "AND photo_tags.photo_id = :id", "id", photo.Id));
-
-		while (reader.Read ()) {
-		        if (reader [0] != null) {
-				uint tag_id = Convert.ToUInt32 (reader [0]);
-				Tag tag = Core.Database.Tags.Get (tag_id) as Tag;
-				photo.AddTagUnsafely (tag);
-			}
-			if (reader [1] != null) {
-				uint version_id = Convert.ToUInt32 (reader [1]);
-				string name = reader[2].ToString ();
-				System.Uri uri = new System.Uri (reader[3].ToString ());
-				bool is_protected = Convert.ToBoolean (reader[4]);	
-				photo.AddVersionUnsafely (version_id, uri, name, is_protected);
-			}
-		}
-		reader.Close();
-	}
-
 	public override DbItem Get (uint id)
 	{
 		Photo photo = LookupInCache (id) as Photo;
@@ -313,7 +297,11 @@ public class PhotoStore : DbStore {
 		if (reader.Read ()) {
 			photo = new Photo (id,
 				Convert.ToInt64 (reader [0]),
+#if MONO_2_0
 				new System.Uri (reader [1].ToString ()));
+#else
+				new System.Uri (reader [1].ToString (), true));
+#endif
 
 			photo.Description = reader[2].ToString ();
 			photo.RollId = Convert.ToUInt32 (reader[3]);
@@ -389,22 +377,16 @@ public class PhotoStore : DbStore {
 	{
 		EmitRemoved (items);
 
-		StringBuilder query_builder = new StringBuilder ();
-		StringBuilder tv_query_builder = new StringBuilder ();
+		ArrayList query_builder = new ArrayList (items.Length);
 		for (int i = 0; i < items.Length; i++) {
-			if (i > 0) {
-				query_builder.Append (" OR ");
-				tv_query_builder.Append (" OR ");
-			}
-
-			query_builder.Append (String.Format ("id = {0}", items[i].Id));
-			tv_query_builder.Append (String.Format ("photo_id = {0}", items[i].Id));
+			query_builder.Add (String.Format ("{0}", items[i].Id));
 			RemoveFromCache (items[i]);
 		}
 
-		Database.ExecuteNonQuery (String.Format ("DELETE FROM photos WHERE {0}", query_builder.ToString ()));
-		Database.ExecuteNonQuery (String.Format ("DELETE FROM photo_tags WHERE {0}", tv_query_builder.ToString ()));
-		Database.ExecuteNonQuery (String.Format ("DELETE FROM photo_versions WHERE {0}", tv_query_builder.ToString ()));
+		String id_list = String.Join ("','", ((string []) query_builder.ToArray (typeof (string))));
+		Database.ExecuteNonQuery (String.Format ("DELETE FROM photos WHERE id IN ('{0}')", id_list));
+		Database.ExecuteNonQuery (String.Format ("DELETE FROM photo_tags WHERE photo_id IN ('{0}')", id_list));
+		Database.ExecuteNonQuery (String.Format ("DELETE FROM photo_versions WHERE photo_id IN ('{0}')", id_list));
 
 	}
 
@@ -446,7 +428,7 @@ public class PhotoStore : DbStore {
 			"description", photo.Description,
 			"default_version_id", photo.DefaultVersionId,
 			"time", DbUtils.UnixTimeFromDateTime (photo.Time),
-			"uri", photo.VersionUri (Photo.OriginalVersionId).ToString (),
+			"uri", photo.VersionUri (Photo.OriginalVersionId).OriginalString,
 			"rating", String.Format ("{0}", photo.Rating),
 			"id", photo.Id));
 
@@ -535,6 +517,7 @@ public class PhotoStore : DbStore {
 
 	public Photo [] Query (string query)
 	{
+		uint timer = Log.DebugTimerStart ("Query: " + query);
 		SqliteDataReader reader = Database.Query(query);
 
 		ArrayList version_list = new ArrayList ();
@@ -546,7 +529,11 @@ public class PhotoStore : DbStore {
 			if (photo == null) {
 				photo = new Photo (id,
 						   Convert.ToInt64 (reader [1]),
+#if MONO_2_0
 						   new System.Uri (reader [2].ToString ()));
+#else
+						   new System.Uri (reader [2].ToString (), true));
+#endif
 				
 				photo.Description = reader[3].ToString ();
 				photo.RollId = Convert.ToUInt32 (reader[4]);
@@ -576,6 +563,7 @@ public class PhotoStore : DbStore {
 			//Console.WriteLine ("Skipped Loading Data");
 		}
 
+		Log.DebugTimerPrint (timer, "Query took {0}");
 		return id_list.ToArray (typeof (Photo)) as Photo [];
 	}
 
@@ -675,7 +663,6 @@ public class PhotoStore : DbStore {
 			query_builder.Append (String.Join (" AND ", ((String []) where_clauses.ToArray (typeof(String)))));
 		}
 		query_builder.Append (" ORDER BY photos.time");
-		Console.WriteLine ("Query: {0}", query_builder.ToString());
 		return Query (query_builder.ToString ());
 	}
 }
