@@ -172,9 +172,14 @@ namespace FSpot {
 	
 		public void UpdateRating ()
 		{
-			rating.Changed -= HandleRatingChanged;
 			if (Item.IsValid)
-				rating.Value = (int)Item.Current.Rating;
+				UpdateRating ((int)Item.Current.Rating);
+		}
+
+		public void UpdateRating (int r)
+		{
+			rating.Changed -= HandleRatingChanged;
+			rating.Value = r;
 			rating.Changed += HandleRatingChanged;
 		}
 
@@ -490,7 +495,7 @@ namespace FSpot {
 			HBox inner_hbox = new HBox (false, 2);
 			//inner_hbox.BorderWidth = 6;
 	
-			tag_view = new Widgets.TagView ();
+			tag_view = new Widgets.TagView (MainWindow.ToolTips);
 			inner_hbox.PackStart (tag_view, false, true, 0);
 	
 			Label comment = new Label (Catalog.GetString ("Comment:"));
