@@ -11,7 +11,7 @@ namespace FSpot {
 	public class XScreenSaverSlide : Gtk.Window {
 		public const string ScreenSaverEnviroment = "XSCREENSAVER_WINDOW";
 
-		public XScreenSaverSlide () : base ("")
+		public XScreenSaverSlide () : base (String.Empty)
 		{
 		}
 	       
@@ -268,6 +268,8 @@ namespace FSpot {
 						next.Dispose ();
 
 					next = GetScaled (photos [0]);
+					if (next == null)
+						next = GetScaled (PixbufUtils.ShallowCopy (PixbufUtils.ErrorPixbuf));
 					next_idx = 0;
 					StartTweenIdle ();
 					
