@@ -1,29 +1,10 @@
 using System;
 using System.Collections;
+using FSpot.Query;
+using FSpot.Utils;
 
 namespace FSpot {
 	public class TimeAdaptor : GroupAdaptor, FSpot.ILimitable {
-		public PhotoQuery query;
-		public override PhotoQuery Query {
-			get {
-				return query;
-			}
-		}
-		
-		private bool order_ascending = false;
-		public override bool OrderAscending {
-			get {
-				return order_ascending;
-			}
-			set {
-				if (value != order_ascending) {
-					order_ascending = value;
-					Reload();
-				}
-			}
-		
-		}
-
 		ArrayList years = new ArrayList ();
 		struct YearData {
 			public int Year;
@@ -69,7 +50,7 @@ namespace FSpot {
 		
 		public void SetLimits (int min, int max) 
 		{
-			Console.WriteLine ("min {0} max {1}", min, max);
+			//Console.WriteLine ("min {0} max {1}", min, max);
 			DateTime start = DateFromIndex (min);
 
 			DateTime end = DateFromIndex(max);
@@ -84,11 +65,11 @@ namespace FSpot {
 
 		public void SetLimits (DateTime start, DateTime end)
 		{
-			Console.WriteLine ("{0} {1}", start, end);
+			//Console.WriteLine ("{0} {1}", start, end);
 			if (start > end)
-				query.Range = new PhotoStore.DateRange (end, start);
+				query.Range = new DateRange (end, start);
 			else 
-				query.Range = new PhotoStore.DateRange (start, end);
+				query.Range = new DateRange (start, end);
 		}
 
 		public override int Count ()
@@ -210,19 +191,14 @@ namespace FSpot {
 		
 		}
 
-		private void HandleChanged (IBrowsableCollection sender)
-		{
-			Console.WriteLine ("Reloading");
-			Reload ();
-		}
-		
 		public override event ChangedHandler Changed;
 		
-		public override void Reload () 
+		protected override void Reload () 
 		{
 			years.Clear ();
 
-			Photo [] photos = query.Store.Query (null, null);
+			Photo [] photos = query.Store.Query ((Tag [])null, null, null, null, null);
+
 			Array.Sort (query.Photos);
 			Array.Sort (photos);
 
@@ -261,11 +237,8 @@ namespace FSpot {
 		}
 
 
-		public TimeAdaptor (PhotoQuery query) {
-			this.query = query;
-			this.query.Changed += HandleChanged;
-			
-			Reload ();
-		}
+		public TimeAdaptor (PhotoQuery query, bool order_ascending) 
+			: base (query, order_ascending)
+		{ }
 	}
 }
