@@ -28,6 +28,7 @@ namespace FSpot.UI.Dialog
 				"",
 				"Active Contributors to this release",
 				"\tLorenzo Milesi",
+				"\tRuben Vermeersch",
 				"",
 				"Contributors",
 				"\tAaron Bockover",
@@ -53,7 +54,6 @@ namespace FSpot.UI.Dialog
 				"\tNat Friedman",
 				"\tPatanjali Somayaji",
 				"\tPeter Johanson",
-				"\tRuben Vermeersch",
 				"\tTambet Ingo",
 				"\tThomas Van Machelen",
 				"\tTodd Berman",
@@ -64,7 +64,7 @@ namespace FSpot.UI.Dialog
 				"In memory Of",
 				"\tEttore Perazzoli",
 			};
-			Comments = "Photo management for GNOME";
+			Comments = Catalog.GetString ("Photo management for GNOME");
 			Copyright = Catalog.GetString ("Copyright \x00a9 2003-2008 Novell Inc.");
 			Documenters = new string[] {
 				"Aaron Bockover",
@@ -86,7 +86,7 @@ namespace FSpot.UI.Dialog
 				Console.WriteLine (e);
 				License = "GPL v2";
 			}
-			Logo = PixbufUtils.LoadFromAssembly ("f-spot-logo.svg");
+			Logo = new Gdk.Pixbuf (System.Reflection.Assembly.GetEntryAssembly (), "f-spot-logo.svg");
 	#if !GTK_2_11
 			Name = "F-Spot";
 	#endif
